﻿namespace Section5_2.ViewModels
{
    using System;
    using YKToolkit.Bindings;

    public class MainViewModel : NotificationObject
    {
        private DelegateCommand readFileCommand;
        /// <summary>
        /// ファイル読込コマンドを取得します。
        /// </summary>
        public DelegateCommand ReadFileCommand
        {
            get
            {
                return readFileCommand ?? (readFileCommand = new DelegateCommand(_ =>
                {
                    ReadFileCallback = ReadFile;
                }));
            }
        }

        private DelegateCommand writeFileCommand;
        /// <summary>
        /// ファイル書込コマンドを取得します。
        /// </summary>
        public DelegateCommand WriteFileCommand
        {
            get
            {
                return writeFileCommand ?? (writeFileCommand = new DelegateCommand(_ =>
                {
                    WriteFileCallback = WriteFile;
                }));
            }
        }

        private Action<object, bool?> readFileCallback;
        /// <summary>
        /// ファイル読込コールバックを取得または設定します。
        /// </summary>
        public Action<object, bool?> ReadFileCallback
        {
            get { return readFileCallback; }
            set { SetProperty(ref readFileCallback, value); }
        }

        private void ReadFile(object parameter, bool? result)
        {
            if ((result != null) && (result.Value))
            {
                var filenames = parameter as string[];
                if (filenames != null)
                {
                    foreach (var filename in filenames)
                    {
                        System.Console.WriteLine(filename);
                    }
                }
            }

            ReadFileCallback = null;
        }

        private Action<object, bool?> writeFileCallback;
        /// <summary>
        /// ファイル書込コールバックを取得または設定します。
        /// </summary>
        public Action<object, bool?> WriteFileCallback
        {
            get { return writeFileCallback; }
            set { SetProperty(ref writeFileCallback, value); }
        }

        private void WriteFile(object parameter, bool? result)
        {
            if ((result != null) && (result.Value))
            {
                var filename = parameter as string;
                if (!string.IsNullOrEmpty(filename))
                {
                    System.Console.WriteLine(filename);
                }
            }

            WriteFileCallback = null;
        }
    }
}
